@@ -1,5 +1,10 @@
 #' Estimates the linear predictor of a psc object
 #'
+#' A function which created a linear predictor from a model and an external
+#' dataset.  If required, linear predictors will be provided on the response
+#' scale.  For a survival outcome, this will take the form of median survival
+#' estimates.
+#'
 #' @param DC_clean a cleaned data obhject created using dataComb()
 #' @param resp detailing whether the linear predictor shoudl be returned on the natural or response level.  Defaults to the natural scale (resp=F)
 #' @details A function which combines the data from the data cohort against the model parameters of the PSC
@@ -7,14 +12,21 @@
 #' @examples
 #' library(psc)
 #' library(survival)
-#' data("surv.mod")
-#' data("data")
+#' surv.mod <- psc::surv.mod
+#' data <- psc::data
 #' dc <- dataComb(surv.mod,data)
 #' lp <- linPred(dc)
 #' @export
 linPred <- function(DC_clean,resp=FALSE){
+
   mt <- DC_clean$model.type
   cov <- DC_clean$cov;cov
+
+  ## Removing 'trt' from dataset
+  if("trt"%in%colnames(cov)){
+    cov <- cov[,-which(colnames(cov)=="trt")]
+  }
+
   cov_co <- DC_clean$model_extract$cov_co;cov_co
   lp <- cov %*% cov_co
   ret <- lp
